@@ -1,10 +1,13 @@
-#' Write prepro data
+#' @title Write prepro data
+#' 
+#' @description 
+#' `r antaresEditObject:::badge_api_no()`
 #'
 #' This function allows to write load, wind and solar prepro data. Using
-#' \code{character(0)} allows to erase data (cf Examples).
+#' `character(0)` allows to erase data (cf Examples).
 #'
 #' @param area The area where to write prepro data.
-#' @param type Type of data to write : \code{"load"}, \code{"wind"} or \code{"solar"}.
+#' @param type Type of data to write : `"load"`, `"wind"` or `"solar"`.
 #' @param coefficients A 12*6 matrix of monthly values for the primary
 #'   parameters alpha, beta, gamma, delta, theta and mu.
 #' @param daily_profile A 24*12 matrix of hourly / monthly coefficients K(hm)
@@ -17,7 +20,7 @@
 #'   General Reference Guide.
 #' @param overwrite Logical. Overwrite the values if a file already exists.
 #' @param opts List of simulation parameters returned by the function
-#'   \code{antaresRead::setSimulationPath}.
+#'   [antaresRead::setSimulationPath()].
 #'
 #' @export
 #'
@@ -34,20 +37,19 @@
 #' writeSeriesPrepro("fictive_area", type = "solar", daily_profile = character(0))
 #'
 #' }
-writeSeriesPrepro <- function(
-  area,
-  type = c("load", "wind", "solar"),
-  coefficients = NULL,
-  daily_profile = NULL,
-  translation = NULL,
-  conversion = NULL,
-  overwrite = TRUE,
-  opts = antaresRead::simOptions()
-) {
+writeSeriesPrepro <- function(area,
+                              type = c("load", "wind", "solar"),
+                              coefficients = NULL,
+                              daily_profile = NULL,
+                              translation = NULL,
+                              conversion = NULL,
+                              overwrite = TRUE,
+                              opts = antaresRead::simOptions()) {
   
   type <- match.arg(type)
   
-  assertthat::assert_that(class(opts) == "simOptions")
+  assertthat::assert_that(inherits(opts, "simOptions"))
+  api_not_implemented(opts)
   
   check_area_name(area, opts)
   
@@ -73,7 +75,10 @@ writeSeriesPrepro <- function(
     if (!identical(dim(coefficients), c(12L, 6L)) && !identical(coefficients, character(0)))
       stop("'coefficients' must be either a 12*6 matrix or character(0).", call. = FALSE)
     fwrite(
-      x = as.data.table(coefficients), row.names = FALSE, col.names = FALSE, sep = "\t",
+      x = as.data.table(coefficients), 
+      row.names = FALSE, 
+      col.names = FALSE,
+      sep = "\t",
       file = coefficients_file
     )
   }
@@ -83,7 +88,10 @@ writeSeriesPrepro <- function(
     if (!identical(dim(daily_profile), c(24L, 12L)) && !identical(daily_profile, character(0)))
       stop("'daily_profile' must be either a 24*12 matrix or character(0).", call. = FALSE)
     fwrite(
-      x = as.data.table(daily_profile), row.names = FALSE, col.names = FALSE, sep = "\t",
+      x = as.data.table(daily_profile), 
+      row.names = FALSE,
+      col.names = FALSE,
+      sep = "\t",
       file = daily_profile_file
     )
   }
@@ -96,7 +104,10 @@ writeSeriesPrepro <- function(
       stop("'translation' must be either a vector of length 8760, a 8760*1 matrix, or character(0).",
            call. = FALSE)
     fwrite(
-      x = as.data.table(translation), row.names = FALSE, col.names = FALSE, sep = "\t",
+      x = as.data.table(translation), 
+      row.names = FALSE, 
+      col.names = FALSE, 
+      sep = "\t",
       file = translation_file
     )
   }
@@ -106,7 +117,10 @@ writeSeriesPrepro <- function(
     if (NROW(conversion) != 2 && !identical(translation, character(0)))
       stop("'conversion' must be either a 2*N matrix or character(0).", call. = FALSE)
     fwrite(
-      x = as.data.table(conversion), row.names = FALSE, col.names = FALSE, sep = "\t",
+      x = as.data.table(conversion),
+      row.names = FALSE,
+      col.names = FALSE, 
+      sep = "\t",
       file = conversion_file
     )
   }
